@@ -4,14 +4,15 @@ setClass("theta", representation(kinpar = "vector", specpar = "list",
 	prel = "vector", coh="vector", drel = "vector", cohirf="vector", 
 	kinpar2 = "vector", kin2scal="vector", jvec = "vector", 
 	anipar = "vector", peakpar = "list", amplitudes = "vector", 
-	extracomp = "list"), 
+	shift = "vector", amps = "list", kinscalspecial = "list"), 
 	prototype = list(kinpar = vector(), specpar = list(), 
 	irfpar = vector(), parmu = list(), partau = vector(), 
 	clpequ = vector(), specdisppar = list(), drel = vector(), 
 	coh = vector(), kinscal = vector(), prel = vector(),
 	jvec = vector(), cohirf= vector(), kinpar2 = vector(), 
 	kin2scal = vector(), anipar = vector(), peakpar = list(),
-	amplitudes=vector(), extracomp = list() ))
+	amplitudes=vector(), shift = vector(), amps = list(),
+          kinscalspecial = list() ))
 
 
 
